# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/active_contracts_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/active_contracts_service.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B ActiveContractsServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5com/daml/ledger/api/v1/active_contracts_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/event.proto\x1a/com/daml/ledger/api/v1/transaction_filter.proto\"\x95\x01\n\x19GetActiveContractsRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\x12\x41\n\x06\x66ilter\x18\x02 \x01(\x0b\x32).com.daml.ledger.api.v1.TransactionFilterR\x06\x66ilter\x12\x18\n\x07verbose\x18\x03 \x01(\x08R\x07verbose\"\xa6\x01\n\x1aGetActiveContractsResponse\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\x12\x1f\n\x0bworkflow_id\x18\x02 \x01(\tR\nworkflowId\x12O\n\x10\x61\x63tive_contracts\x18\x03 \x03(\x0b\x32$.com.daml.ledger.api.v1.CreatedEventR\x0f\x61\x63tiveContracts2\x97\x01\n\x16\x41\x63tiveContractsService\x12}\n\x12GetActiveContracts\x12\x31.com.daml.ledger.api.v1.GetActiveContractsRequest\x1a\x32.com.daml.ledger.api.v1.GetActiveContractsResponse0\x01\x42\xa4\x01\n\x16\x63om.daml.ledger.api.v1B ActiveContractsServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2.DESCRIPTOR,com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__filter__pb2.DESCRIPTOR,])




_GETACTIVECONTRACTSREQUEST = _descriptor.Descriptor(
  name='GetActiveContractsRequest',
  full_name='com.daml.ledger.api.v1.GetActiveContractsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetActiveContractsRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='com.daml.ledger.api.v1.GetActiveContractsRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='filter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbose', full_name='com.daml.ledger.api.v1.GetActiveContractsRequest.verbose', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='verbose', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=316,
)


_GETACTIVECONTRACTSRESPONSE = _descriptor.Descriptor(
  name='GetActiveContractsResponse',
  full_name='com.daml.ledger.api.v1.GetActiveContractsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='com.daml.ledger.api.v1.GetActiveContractsResponse.offset', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='com.daml.ledger.api.v1.GetActiveContractsResponse.workflow_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_contracts', full_name='com.daml.ledger.api.v1.GetActiveContractsResponse.active_contracts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='activeContracts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=485,
)

_GETACTIVECONTRACTSREQUEST.fields_by_name['filter'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__filter__pb2._TRANSACTIONFILTER
_GETACTIVECONTRACTSRESPONSE.fields_by_name['active_contracts'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2._CREATEDEVENT
DESCRIPTOR.message_types_by_name['GetActiveContractsRequest'] = _GETACTIVECONTRACTSREQUEST
DESCRIPTOR.message_types_by_name['GetActiveContractsResponse'] = _GETACTIVECONTRACTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetActiveContractsRequest = _reflection.GeneratedProtocolMessageType('GetActiveContractsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVECONTRACTSREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.active_contracts_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetActiveContractsRequest)
  })
_sym_db.RegisterMessage(GetActiveContractsRequest)

GetActiveContractsResponse = _reflection.GeneratedProtocolMessageType('GetActiveContractsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVECONTRACTSRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.active_contracts_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetActiveContractsResponse)
  })
_sym_db.RegisterMessage(GetActiveContractsResponse)


DESCRIPTOR._options = None

_ACTIVECONTRACTSSERVICE = _descriptor.ServiceDescriptor(
  name='ActiveContractsService',
  full_name='com.daml.ledger.api.v1.ActiveContractsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=488,
  serialized_end=639,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetActiveContracts',
    full_name='com.daml.ledger.api.v1.ActiveContractsService.GetActiveContracts',
    index=0,
    containing_service=None,
    input_type=_GETACTIVECONTRACTSREQUEST,
    output_type=_GETACTIVECONTRACTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTIVECONTRACTSSERVICE)

DESCRIPTOR.services_by_name['ActiveContractsService'] = _ACTIVECONTRACTSSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/value.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\017ValueOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"com/daml/ledger/api/v1/value.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\x1bgoogle/protobuf/empty.proto\"\xa0\x05\n\x05Value\x12\x38\n\x06record\x18\x01 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.RecordH\x00R\x06record\x12;\n\x07variant\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v1.VariantH\x00R\x07variant\x12!\n\x0b\x63ontract_id\x18\x03 \x01(\tH\x00R\ncontractId\x12\x32\n\x04list\x18\x04 \x01(\x0b\x32\x1c.com.daml.ledger.api.v1.ListH\x00R\x04list\x12\x1a\n\x05int64\x18\x05 \x01(\x12\x42\x02\x30\x01H\x00R\x05int64\x12\x1a\n\x07numeric\x18\x06 \x01(\tH\x00R\x07numeric\x12\x14\n\x04text\x18\x08 \x01(\tH\x00R\x04text\x12\"\n\ttimestamp\x18\t \x01(\x10\x42\x02\x30\x01H\x00R\ttimestamp\x12\x16\n\x05party\x18\x0b \x01(\tH\x00R\x05party\x12\x14\n\x04\x62ool\x18\x0c \x01(\x08H\x00R\x04\x62ool\x12,\n\x04unit\x18\r \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x04unit\x12\x14\n\x04\x64\x61te\x18\x0e \x01(\x05H\x00R\x04\x64\x61te\x12>\n\x08optional\x18\x0f \x01(\x0b\x32 .com.daml.ledger.api.v1.OptionalH\x00R\x08optional\x12/\n\x03map\x18\x10 \x01(\x0b\x32\x1b.com.daml.ledger.api.v1.MapH\x00R\x03map\x12\x32\n\x04\x65num\x18\x11 \x01(\x0b\x32\x1c.com.daml.ledger.api.v1.EnumH\x00R\x04\x65num\x12\x39\n\x07gen_map\x18\x12 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.GenMapH\x00R\x06genMapB\x05\n\x03Sum\"\x86\x01\n\x06Record\x12?\n\trecord_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\x08recordId\x12;\n\x06\x66ields\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.RecordFieldR\x06\x66ields\"X\n\x0bRecordField\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x05value\"s\n\nIdentifier\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12\x1f\n\x0bmodule_name\x18\x03 \x01(\tR\nmoduleName\x12\x1f\n\x0b\x65ntity_name\x18\x04 \x01(\tR\nentityNameJ\x04\x08\x02\x10\x03\"\xa3\x01\n\x07Variant\x12\x41\n\nvariant_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\tvariantId\x12 \n\x0b\x63onstructor\x18\x02 \x01(\tR\x0b\x63onstructor\x12\x33\n\x05value\x18\x03 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x05value\"e\n\x04\x45num\x12;\n\x07\x65num_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\x06\x65numId\x12 \n\x0b\x63onstructor\x18\x02 \x01(\tR\x0b\x63onstructor\"A\n\x04List\x12\x39\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x08\x65lements\"?\n\x08Optional\x12\x33\n\x05value\x18\x01 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x05value\"\x92\x01\n\x03Map\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.com.daml.ledger.api.v1.Map.EntryR\x07\x65ntries\x1aN\n\x05\x45ntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x05value\"\xb7\x01\n\x06GenMap\x12>\n\x07\x65ntries\x18\x01 \x03(\x0b\x32$.com.daml.ledger.api.v1.GenMap.EntryR\x07\x65ntries\x1am\n\x05\x45ntry\x12/\n\x03key\x18\x01 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x03key\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x05valueB\x93\x01\n\x16\x63om.daml.ledger.api.v1B\x0fValueOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='com.daml.ledger.api.v1.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='com.daml.ledger.api.v1.Value.record', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='record', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='com.daml.ledger.api.v1.Value.variant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='variant', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_id', full_name='com.daml.ledger.api.v1.Value.contract_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='contractId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list', full_name='com.daml.ledger.api.v1.Value.list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='list', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64', full_name='com.daml.ledger.api.v1.Value.int64', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', json_name='int64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='com.daml.ledger.api.v1.Value.numeric', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numeric', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='com.daml.ledger.api.v1.Value.text', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='text', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.daml.ledger.api.v1.Value.timestamp', index=7,
      number=9, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party', full_name='com.daml.ledger.api.v1.Value.party', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='party', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool', full_name='com.daml.ledger.api.v1.Value.bool', index=9,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bool', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='com.daml.ledger.api.v1.Value.unit', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='unit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='com.daml.ledger.api.v1.Value.date', index=11,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='date', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='com.daml.ledger.api.v1.Value.optional', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='optional', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map', full_name='com.daml.ledger.api.v1.Value.map', index=13,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='map', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum', full_name='com.daml.ledger.api.v1.Value.enum', index=14,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enum', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gen_map', full_name='com.daml.ledger.api.v1.Value.gen_map', index=15,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='genMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='com.daml.ledger.api.v1.Value.Sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=92,
  serialized_end=764,
)


_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='com.daml.ledger.api.v1.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record_id', full_name='com.daml.ledger.api.v1.Record.record_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='recordId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='com.daml.ledger.api.v1.Record.fields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fields', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=901,
)


_RECORDFIELD = _descriptor.Descriptor(
  name='RecordField',
  full_name='com.daml.ledger.api.v1.RecordField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='com.daml.ledger.api.v1.RecordField.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.daml.ledger.api.v1.RecordField.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=991,
)


_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='com.daml.ledger.api.v1.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_id', full_name='com.daml.ledger.api.v1.Identifier.package_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='packageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='com.daml.ledger.api.v1.Identifier.module_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='moduleName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity_name', full_name='com.daml.ledger.api.v1.Identifier.entity_name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1108,
)


_VARIANT = _descriptor.Descriptor(
  name='Variant',
  full_name='com.daml.ledger.api.v1.Variant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variant_id', full_name='com.daml.ledger.api.v1.Variant.variant_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='variantId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constructor', full_name='com.daml.ledger.api.v1.Variant.constructor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='constructor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.daml.ledger.api.v1.Variant.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1274,
)


_ENUM = _descriptor.Descriptor(
  name='Enum',
  full_name='com.daml.ledger.api.v1.Enum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enum_id', full_name='com.daml.ledger.api.v1.Enum.enum_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enumId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constructor', full_name='com.daml.ledger.api.v1.Enum.constructor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='constructor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1276,
  serialized_end=1377,
)


_LIST = _descriptor.Descriptor(
  name='List',
  full_name='com.daml.ledger.api.v1.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='com.daml.ledger.api.v1.List.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='elements', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1444,
)


_OPTIONAL = _descriptor.Descriptor(
  name='Optional',
  full_name='com.daml.ledger.api.v1.Optional',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.daml.ledger.api.v1.Optional.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1509,
)


_MAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='com.daml.ledger.api.v1.Map.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.daml.ledger.api.v1.Map.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.daml.ledger.api.v1.Map.Entry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1580,
  serialized_end=1658,
)

_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='com.daml.ledger.api.v1.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='com.daml.ledger.api.v1.Map.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MAP_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1658,
)


_GENMAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='com.daml.ledger.api.v1.GenMap.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.daml.ledger.api.v1.GenMap.Entry.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.daml.ledger.api.v1.GenMap.Entry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1735,
  serialized_end=1844,
)

_GENMAP = _descriptor.Descriptor(
  name='GenMap',
  full_name='com.daml.ledger.api.v1.GenMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='com.daml.ledger.api.v1.GenMap.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GENMAP_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1844,
)

_VALUE.fields_by_name['record'].message_type = _RECORD
_VALUE.fields_by_name['variant'].message_type = _VARIANT
_VALUE.fields_by_name['list'].message_type = _LIST
_VALUE.fields_by_name['unit'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_VALUE.fields_by_name['optional'].message_type = _OPTIONAL
_VALUE.fields_by_name['map'].message_type = _MAP
_VALUE.fields_by_name['enum'].message_type = _ENUM
_VALUE.fields_by_name['gen_map'].message_type = _GENMAP
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['record'])
_VALUE.fields_by_name['record'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['variant'])
_VALUE.fields_by_name['variant'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['contract_id'])
_VALUE.fields_by_name['contract_id'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['list'])
_VALUE.fields_by_name['list'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['int64'])
_VALUE.fields_by_name['int64'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['numeric'])
_VALUE.fields_by_name['numeric'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['text'])
_VALUE.fields_by_name['text'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['timestamp'])
_VALUE.fields_by_name['timestamp'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['party'])
_VALUE.fields_by_name['party'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['bool'])
_VALUE.fields_by_name['bool'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['unit'])
_VALUE.fields_by_name['unit'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['date'])
_VALUE.fields_by_name['date'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['optional'])
_VALUE.fields_by_name['optional'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['map'])
_VALUE.fields_by_name['map'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['enum'])
_VALUE.fields_by_name['enum'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_VALUE.oneofs_by_name['Sum'].fields.append(
  _VALUE.fields_by_name['gen_map'])
_VALUE.fields_by_name['gen_map'].containing_oneof = _VALUE.oneofs_by_name['Sum']
_RECORD.fields_by_name['record_id'].message_type = _IDENTIFIER
_RECORD.fields_by_name['fields'].message_type = _RECORDFIELD
_RECORDFIELD.fields_by_name['value'].message_type = _VALUE
_VARIANT.fields_by_name['variant_id'].message_type = _IDENTIFIER
_VARIANT.fields_by_name['value'].message_type = _VALUE
_ENUM.fields_by_name['enum_id'].message_type = _IDENTIFIER
_LIST.fields_by_name['elements'].message_type = _VALUE
_OPTIONAL.fields_by_name['value'].message_type = _VALUE
_MAP_ENTRY.fields_by_name['value'].message_type = _VALUE
_MAP_ENTRY.containing_type = _MAP
_MAP.fields_by_name['entries'].message_type = _MAP_ENTRY
_GENMAP_ENTRY.fields_by_name['key'].message_type = _VALUE
_GENMAP_ENTRY.fields_by_name['value'].message_type = _VALUE
_GENMAP_ENTRY.containing_type = _GENMAP
_GENMAP.fields_by_name['entries'].message_type = _GENMAP_ENTRY
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['Record'] = _RECORD
DESCRIPTOR.message_types_by_name['RecordField'] = _RECORDFIELD
DESCRIPTOR.message_types_by_name['Identifier'] = _IDENTIFIER
DESCRIPTOR.message_types_by_name['Variant'] = _VARIANT
DESCRIPTOR.message_types_by_name['Enum'] = _ENUM
DESCRIPTOR.message_types_by_name['List'] = _LIST
DESCRIPTOR.message_types_by_name['Optional'] = _OPTIONAL
DESCRIPTOR.message_types_by_name['Map'] = _MAP
DESCRIPTOR.message_types_by_name['GenMap'] = _GENMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Value)
  })
_sym_db.RegisterMessage(Value)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), {
  'DESCRIPTOR' : _RECORD,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Record)
  })
_sym_db.RegisterMessage(Record)

RecordField = _reflection.GeneratedProtocolMessageType('RecordField', (_message.Message,), {
  'DESCRIPTOR' : _RECORDFIELD,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.RecordField)
  })
_sym_db.RegisterMessage(RecordField)

Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Identifier)
  })
_sym_db.RegisterMessage(Identifier)

Variant = _reflection.GeneratedProtocolMessageType('Variant', (_message.Message,), {
  'DESCRIPTOR' : _VARIANT,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Variant)
  })
_sym_db.RegisterMessage(Variant)

Enum = _reflection.GeneratedProtocolMessageType('Enum', (_message.Message,), {
  'DESCRIPTOR' : _ENUM,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Enum)
  })
_sym_db.RegisterMessage(Enum)

List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
  'DESCRIPTOR' : _LIST,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.List)
  })
_sym_db.RegisterMessage(List)

Optional = _reflection.GeneratedProtocolMessageType('Optional', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONAL,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Optional)
  })
_sym_db.RegisterMessage(Optional)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _MAP_ENTRY,
    '__module__' : 'com.daml.ledger.api.v1.value_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Map.Entry)
    })
  ,
  'DESCRIPTOR' : _MAP,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Map)
  })
_sym_db.RegisterMessage(Map)
_sym_db.RegisterMessage(Map.Entry)

GenMap = _reflection.GeneratedProtocolMessageType('GenMap', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _GENMAP_ENTRY,
    '__module__' : 'com.daml.ledger.api.v1.value_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GenMap.Entry)
    })
  ,
  'DESCRIPTOR' : _GENMAP,
  '__module__' : 'com.daml.ledger.api.v1.value_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GenMap)
  })
_sym_db.RegisterMessage(GenMap)
_sym_db.RegisterMessage(GenMap.Entry)


DESCRIPTOR._options = None
_VALUE.fields_by_name['int64']._options = None
_VALUE.fields_by_name['timestamp']._options = None
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/ledger_configuration_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/ledger_configuration_service.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B$LedgerConfigurationServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9com/daml/ledger/api/v1/ledger_configuration_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\x1egoogle/protobuf/duration.proto\"<\n\x1dGetLedgerConfigurationRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\"\x80\x01\n\x1eGetLedgerConfigurationResponse\x12^\n\x14ledger_configuration\x18\x01 \x01(\x0b\x32+.com.daml.ledger.api.v1.LedgerConfigurationR\x13ledgerConfiguration\"r\n\x13LedgerConfiguration\x12O\n\x16max_deduplication_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x14maxDeduplicationTimeJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\x32\xa8\x01\n\x1aLedgerConfigurationService\x12\x89\x01\n\x16GetLedgerConfiguration\x12\x35.com.daml.ledger.api.v1.GetLedgerConfigurationRequest\x1a\x36.com.daml.ledger.api.v1.GetLedgerConfigurationResponse0\x01\x42\xa8\x01\n\x16\x63om.daml.ledger.api.v1B$LedgerConfigurationServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_GETLEDGERCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GetLedgerConfigurationRequest',
  full_name='com.daml.ledger.api.v1.GetLedgerConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetLedgerConfigurationRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=177,
)


_GETLEDGERCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GetLedgerConfigurationResponse',
  full_name='com.daml.ledger.api.v1.GetLedgerConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_configuration', full_name='com.daml.ledger.api.v1.GetLedgerConfigurationResponse.ledger_configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerConfiguration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=308,
)


_LEDGERCONFIGURATION = _descriptor.Descriptor(
  name='LedgerConfiguration',
  full_name='com.daml.ledger.api.v1.LedgerConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_deduplication_time', full_name='com.daml.ledger.api.v1.LedgerConfiguration.max_deduplication_time', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxDeduplicationTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=424,
)

_GETLEDGERCONFIGURATIONRESPONSE.fields_by_name['ledger_configuration'].message_type = _LEDGERCONFIGURATION
_LEDGERCONFIGURATION.fields_by_name['max_deduplication_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['GetLedgerConfigurationRequest'] = _GETLEDGERCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerConfigurationResponse'] = _GETLEDGERCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['LedgerConfiguration'] = _LEDGERCONFIGURATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetLedgerConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERCONFIGURATIONREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.ledger_configuration_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerConfigurationRequest)
  })
_sym_db.RegisterMessage(GetLedgerConfigurationRequest)

GetLedgerConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetLedgerConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERCONFIGURATIONRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.ledger_configuration_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerConfigurationResponse)
  })
_sym_db.RegisterMessage(GetLedgerConfigurationResponse)

LedgerConfiguration = _reflection.GeneratedProtocolMessageType('LedgerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERCONFIGURATION,
  '__module__' : 'com.daml.ledger.api.v1.ledger_configuration_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.LedgerConfiguration)
  })
_sym_db.RegisterMessage(LedgerConfiguration)


DESCRIPTOR._options = None

_LEDGERCONFIGURATIONSERVICE = _descriptor.ServiceDescriptor(
  name='LedgerConfigurationService',
  full_name='com.daml.ledger.api.v1.LedgerConfigurationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=427,
  serialized_end=595,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLedgerConfiguration',
    full_name='com.daml.ledger.api.v1.LedgerConfigurationService.GetLedgerConfiguration',
    index=0,
    containing_service=None,
    input_type=_GETLEDGERCONFIGURATIONREQUEST,
    output_type=_GETLEDGERCONFIGURATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LEDGERCONFIGURATIONSERVICE)

DESCRIPTOR.services_by_name['LedgerConfigurationService'] = _LEDGERCONFIGURATIONSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/ledger_identity_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/ledger_identity_service.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\037LedgerIdentityServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4com/daml/ledger/api/v1/ledger_identity_service.proto\x12\x16\x63om.daml.ledger.api.v1\"\x1a\n\x18GetLedgerIdentityRequest\"8\n\x19GetLedgerIdentityResponse\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId2\x91\x01\n\x15LedgerIdentityService\x12x\n\x11GetLedgerIdentity\x12\x30.com.daml.ledger.api.v1.GetLedgerIdentityRequest\x1a\x31.com.daml.ledger.api.v1.GetLedgerIdentityResponseB\xa3\x01\n\x16\x63om.daml.ledger.api.v1B\x1fLedgerIdentityServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
)




_GETLEDGERIDENTITYREQUEST = _descriptor.Descriptor(
  name='GetLedgerIdentityRequest',
  full_name='com.daml.ledger.api.v1.GetLedgerIdentityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=106,
)


_GETLEDGERIDENTITYRESPONSE = _descriptor.Descriptor(
  name='GetLedgerIdentityResponse',
  full_name='com.daml.ledger.api.v1.GetLedgerIdentityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetLedgerIdentityResponse.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=164,
)

DESCRIPTOR.message_types_by_name['GetLedgerIdentityRequest'] = _GETLEDGERIDENTITYREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerIdentityResponse'] = _GETLEDGERIDENTITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerIdentityRequest = _reflection.GeneratedProtocolMessageType('GetLedgerIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERIDENTITYREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.ledger_identity_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerIdentityRequest)
  })
_sym_db.RegisterMessage(GetLedgerIdentityRequest)

GetLedgerIdentityResponse = _reflection.GeneratedProtocolMessageType('GetLedgerIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERIDENTITYRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.ledger_identity_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerIdentityResponse)
  })
_sym_db.RegisterMessage(GetLedgerIdentityResponse)


DESCRIPTOR._options = None

_LEDGERIDENTITYSERVICE = _descriptor.ServiceDescriptor(
  name='LedgerIdentityService',
  full_name='com.daml.ledger.api.v1.LedgerIdentityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=167,
  serialized_end=312,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLedgerIdentity',
    full_name='com.daml.ledger.api.v1.LedgerIdentityService.GetLedgerIdentity',
    index=0,
    containing_service=None,
    input_type=_GETLEDGERIDENTITYREQUEST,
    output_type=_GETLEDGERIDENTITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LEDGERIDENTITYSERVICE)

DESCRIPTOR.services_by_name['LedgerIdentityService'] = _LEDGERIDENTITYSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/completion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/completion.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\024CompletionOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'com/daml/ledger/api/v1/completion.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\x99\x03\n\nCompletion\x12\x1d\n\ncommand_id\x18\x01 \x01(\tR\tcommandId\x12*\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusR\x06status\x12%\n\x0etransaction_id\x18\x03 \x01(\tR\rtransactionId\x12%\n\x0e\x61pplication_id\x18\x04 \x01(\tR\rapplicationId\x12\x15\n\x06\x61\x63t_as\x18\x05 \x03(\tR\x05\x61\x63tAs\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x08 \x01(\tH\x00R\x13\x64\x65\x64uplicationOffset\x12R\n\x16\x64\x65\x64uplication_duration\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDurationB\x16\n\x14\x64\x65\x64uplication_periodJ\x04\x08\x07\x10\x08R\x0fsubmission_rankB\x98\x01\n\x16\x63om.daml.ledger.api.v1B\x14\x43ompletionOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_COMPLETION = _descriptor.Descriptor(
  name='Completion',
  full_name='com.daml.ledger.api.v1.Completion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_id', full_name='com.daml.ledger.api.v1.Completion.command_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commandId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.daml.ledger.api.v1.Completion.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.daml.ledger.api.v1.Completion.transaction_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transactionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='com.daml.ledger.api.v1.Completion.application_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='act_as', full_name='com.daml.ledger.api.v1.Completion.act_as', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actAs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='com.daml.ledger.api.v1.Completion.submission_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='submissionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_offset', full_name='com.daml.ledger.api.v1.Completion.deduplication_offset', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deduplicationOffset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_duration', full_name='com.daml.ledger.api.v1.Completion.deduplication_duration', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deduplicationDuration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='deduplication_period', full_name='com.daml.ledger.api.v1.Completion.deduplication_period',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=158,
  serialized_end=567,
)

_COMPLETION.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_COMPLETION.fields_by_name['deduplication_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMPLETION.oneofs_by_name['deduplication_period'].fields.append(
  _COMPLETION.fields_by_name['deduplication_offset'])
_COMPLETION.fields_by_name['deduplication_offset'].containing_oneof = _COMPLETION.oneofs_by_name['deduplication_period']
_COMPLETION.oneofs_by_name['deduplication_period'].fields.append(
  _COMPLETION.fields_by_name['deduplication_duration'])
_COMPLETION.fields_by_name['deduplication_duration'].containing_oneof = _COMPLETION.oneofs_by_name['deduplication_period']
DESCRIPTOR.message_types_by_name['Completion'] = _COMPLETION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Completion = _reflection.GeneratedProtocolMessageType('Completion', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETION,
  '__module__' : 'com.daml.ledger.api.v1.completion_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Completion)
  })
_sym_db.RegisterMessage(Completion)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .reset_service_pb2 import ResetRequest
from .reset_service_pb2_grpc import ResetServiceStub
from .time_service_pb2 import GetTimeRequest, GetTimeResponse, SetTimeRequest
from .time_service_pb2_grpc import TimeServiceStub

__all__ = [
    "GetTimeRequest",
    "GetTimeResponse",
    "ResetRequest",
    "ResetServiceStub",
    "SetTimeRequest",
    "TimeServiceStub",
]



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/commands.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/commands.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\022CommandsOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%com/daml/ledger/api/v1/commands.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/value.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x93\x05\n\x08\x43ommands\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\x12\x1f\n\x0bworkflow_id\x18\x02 \x01(\tR\nworkflowId\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x04 \x01(\tR\tcommandId\x12\x14\n\x05party\x18\x05 \x01(\tR\x05party\x12;\n\x08\x63ommands\x18\x08 \x03(\x0b\x32\x1f.com.daml.ledger.api.v1.CommandR\x08\x63ommands\x12N\n\x12\x64\x65\x64uplication_time\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01H\x00R\x11\x64\x65\x64uplicationTime\x12R\n\x16\x64\x65\x64uplication_duration\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12I\n\x13min_ledger_time_abs\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10minLedgerTimeAbs\x12H\n\x13min_ledger_time_rel\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationR\x10minLedgerTimeRel\x12\x15\n\x06\x61\x63t_as\x18\x0c \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\r \x03(\tR\x06readAs\x12#\n\rsubmission_id\x18\x0e \x01(\tR\x0csubmissionIdB\x16\n\x14\x64\x65\x64uplication_periodJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"\xd4\x02\n\x07\x43ommand\x12?\n\x06\x63reate\x18\x01 \x01(\x0b\x32%.com.daml.ledger.api.v1.CreateCommandH\x00R\x06\x63reate\x12\x45\n\x08\x65xercise\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v1.ExerciseCommandH\x00R\x08\x65xercise\x12T\n\rexerciseByKey\x18\x04 \x01(\x0b\x32,.com.daml.ledger.api.v1.ExerciseByKeyCommandH\x00R\rexerciseByKey\x12`\n\x11\x63reateAndExercise\x18\x03 \x01(\x0b\x32\x30.com.daml.ledger.api.v1.CreateAndExerciseCommandH\x00R\x11\x63reateAndExerciseB\t\n\x07\x63ommand\"\x9f\x01\n\rCreateCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12I\n\x10\x63reate_arguments\x18\x02 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.RecordR\x0f\x63reateArguments\"\xd7\x01\n\x0f\x45xerciseCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0e\x63hoiceArgument\"\xfd\x01\n\x14\x45xerciseByKeyCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12@\n\x0c\x63ontract_key\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0b\x63ontractKey\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0e\x63hoiceArgument\"\x8a\x02\n\x18\x43reateAndExerciseCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12I\n\x10\x63reate_arguments\x18\x02 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.RecordR\x0f\x63reateArguments\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0e\x63hoiceArgumentB\x96\x01\n\x16\x63om.daml.ledger.api.v1B\x12\x43ommandsOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_COMMANDS = _descriptor.Descriptor(
  name='Commands',
  full_name='com.daml.ledger.api.v1.Commands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.Commands.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='com.daml.ledger.api.v1.Commands.workflow_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='com.daml.ledger.api.v1.Commands.application_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_id', full_name='com.daml.ledger.api.v1.Commands.command_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commandId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party', full_name='com.daml.ledger.api.v1.Commands.party', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='party', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commands', full_name='com.daml.ledger.api.v1.Commands.commands', index=5,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commands', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_time', full_name='com.daml.ledger.api.v1.Commands.deduplication_time', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='deduplicationTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_duration', full_name='com.daml.ledger.api.v1.Commands.deduplication_duration', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deduplicationDuration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_ledger_time_abs', full_name='com.daml.ledger.api.v1.Commands.min_ledger_time_abs', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='minLedgerTimeAbs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_ledger_time_rel', full_name='com.daml.ledger.api.v1.Commands.min_ledger_time_rel', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='minLedgerTimeRel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='act_as', full_name='com.daml.ledger.api.v1.Commands.act_as', index=10,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actAs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_as', full_name='com.daml.ledger.api.v1.Commands.read_as', index=11,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='readAs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='com.daml.ledger.api.v1.Commands.submission_id', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='submissionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='deduplication_period', full_name='com.daml.ledger.api.v1.Commands.deduplication_period',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=167,
  serialized_end=826,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='com.daml.ledger.api.v1.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='com.daml.ledger.api.v1.Command.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='create', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exercise', full_name='com.daml.ledger.api.v1.Command.exercise', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='exercise', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exerciseByKey', full_name='com.daml.ledger.api.v1.Command.exerciseByKey', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='exerciseByKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createAndExercise', full_name='com.daml.ledger.api.v1.Command.createAndExercise', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createAndExercise', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='com.daml.ledger.api.v1.Command.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=829,
  serialized_end=1169,
)


_CREATECOMMAND = _descriptor.Descriptor(
  name='CreateCommand',
  full_name='com.daml.ledger.api.v1.CreateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='com.daml.ledger.api.v1.CreateCommand.template_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='templateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_arguments', full_name='com.daml.ledger.api.v1.CreateCommand.create_arguments', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createArguments', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1172,
  serialized_end=1331,
)


_EXERCISECOMMAND = _descriptor.Descriptor(
  name='ExerciseCommand',
  full_name='com.daml.ledger.api.v1.ExerciseCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='com.daml.ledger.api.v1.ExerciseCommand.template_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='templateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_id', full_name='com.daml.ledger.api.v1.ExerciseCommand.contract_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='contractId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice', full_name='com.daml.ledger.api.v1.ExerciseCommand.choice', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='choice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice_argument', full_name='com.daml.ledger.api.v1.ExerciseCommand.choice_argument', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='choiceArgument', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1334,
  serialized_end=1549,
)


_EXERCISEBYKEYCOMMAND = _descriptor.Descriptor(
  name='ExerciseByKeyCommand',
  full_name='com.daml.ledger.api.v1.ExerciseByKeyCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='com.daml.ledger.api.v1.ExerciseByKeyCommand.template_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='templateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_key', full_name='com.daml.ledger.api.v1.ExerciseByKeyCommand.contract_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='contractKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice', full_name='com.daml.ledger.api.v1.ExerciseByKeyCommand.choice', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='choice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice_argument', full_name='com.daml.ledger.api.v1.ExerciseByKeyCommand.choice_argument', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='choiceArgument', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1552,
  serialized_end=1805,
)


_CREATEANDEXERCISECOMMAND = _descriptor.Descriptor(
  name='CreateAndExerciseCommand',
  full_name='com.daml.ledger.api.v1.CreateAndExerciseCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='com.daml.ledger.api.v1.CreateAndExerciseCommand.template_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='templateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_arguments', full_name='com.daml.ledger.api.v1.CreateAndExerciseCommand.create_arguments', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createArguments', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice', full_name='com.daml.ledger.api.v1.CreateAndExerciseCommand.choice', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='choice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice_argument', full_name='com.daml.ledger.api.v1.CreateAndExerciseCommand.choice_argument', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='choiceArgument', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1808,
  serialized_end=2074,
)

_COMMANDS.fields_by_name['commands'].message_type = _COMMAND
_COMMANDS.fields_by_name['deduplication_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMANDS.fields_by_name['deduplication_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMANDS.fields_by_name['min_ledger_time_abs'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDS.fields_by_name['min_ledger_time_rel'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMANDS.oneofs_by_name['deduplication_period'].fields.append(
  _COMMANDS.fields_by_name['deduplication_time'])
_COMMANDS.fields_by_name['deduplication_time'].containing_oneof = _COMMANDS.oneofs_by_name['deduplication_period']
_COMMANDS.oneofs_by_name['deduplication_period'].fields.append(
  _COMMANDS.fields_by_name['deduplication_duration'])
_COMMANDS.fields_by_name['deduplication_duration'].containing_oneof = _COMMANDS.oneofs_by_name['deduplication_period']
_COMMAND.fields_by_name['create'].message_type = _CREATECOMMAND
_COMMAND.fields_by_name['exercise'].message_type = _EXERCISECOMMAND
_COMMAND.fields_by_name['exerciseByKey'].message_type = _EXERCISEBYKEYCOMMAND
_COMMAND.fields_by_name['createAndExercise'].message_type = _CREATEANDEXERCISECOMMAND
_COMMAND.oneofs_by_name['command'].fields.append(
  _COMMAND.fields_by_name['create'])
_COMMAND.fields_by_name['create'].containing_oneof = _COMMAND.oneofs_by_name['command']
_COMMAND.oneofs_by_name['command'].fields.append(
  _COMMAND.fields_by_name['exercise'])
_COMMAND.fields_by_name['exercise'].containing_oneof = _COMMAND.oneofs_by_name['command']
_COMMAND.oneofs_by_name['command'].fields.append(
  _COMMAND.fields_by_name['exerciseByKey'])
_COMMAND.fields_by_name['exerciseByKey'].containing_oneof = _COMMAND.oneofs_by_name['command']
_COMMAND.oneofs_by_name['command'].fields.append(
  _COMMAND.fields_by_name['createAndExercise'])
_COMMAND.fields_by_name['createAndExercise'].containing_oneof = _COMMAND.oneofs_by_name['command']
_CREATECOMMAND.fields_by_name['template_id'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._IDENTIFIER
_CREATECOMMAND.fields_by_name['create_arguments'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._RECORD
_EXERCISECOMMAND.fields_by_name['template_id'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._IDENTIFIER
_EXERCISECOMMAND.fields_by_name['choice_argument'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._VALUE
_EXERCISEBYKEYCOMMAND.fields_by_name['template_id'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._IDENTIFIER
_EXERCISEBYKEYCOMMAND.fields_by_name['contract_key'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._VALUE
_EXERCISEBYKEYCOMMAND.fields_by_name['choice_argument'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._VALUE
_CREATEANDEXERCISECOMMAND.fields_by_name['template_id'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._IDENTIFIER
_CREATEANDEXERCISECOMMAND.fields_by_name['create_arguments'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._RECORD
_CREATEANDEXERCISECOMMAND.fields_by_name['choice_argument'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2._VALUE
DESCRIPTOR.message_types_by_name['Commands'] = _COMMANDS
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['CreateCommand'] = _CREATECOMMAND
DESCRIPTOR.message_types_by_name['ExerciseCommand'] = _EXERCISECOMMAND
DESCRIPTOR.message_types_by_name['ExerciseByKeyCommand'] = _EXERCISEBYKEYCOMMAND
DESCRIPTOR.message_types_by_name['CreateAndExerciseCommand'] = _CREATEANDEXERCISECOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Commands = _reflection.GeneratedProtocolMessageType('Commands', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDS,
  '__module__' : 'com.daml.ledger.api.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Commands)
  })
_sym_db.RegisterMessage(Commands)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
  'DESCRIPTOR' : _COMMAND,
  '__module__' : 'com.daml.ledger.api.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Command)
  })
_sym_db.RegisterMessage(Command)

CreateCommand = _reflection.GeneratedProtocolMessageType('CreateCommand', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMAND,
  '__module__' : 'com.daml.ledger.api.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CreateCommand)
  })
_sym_db.RegisterMessage(CreateCommand)

ExerciseCommand = _reflection.GeneratedProtocolMessageType('ExerciseCommand', (_message.Message,), {
  'DESCRIPTOR' : _EXERCISECOMMAND,
  '__module__' : 'com.daml.ledger.api.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ExerciseCommand)
  })
_sym_db.RegisterMessage(ExerciseCommand)

ExerciseByKeyCommand = _reflection.GeneratedProtocolMessageType('ExerciseByKeyCommand', (_message.Message,), {
  'DESCRIPTOR' : _EXERCISEBYKEYCOMMAND,
  '__module__' : 'com.daml.ledger.api.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ExerciseByKeyCommand)
  })
_sym_db.RegisterMessage(ExerciseByKeyCommand)

CreateAndExerciseCommand = _reflection.GeneratedProtocolMessageType('CreateAndExerciseCommand', (_message.Message,), {
  'DESCRIPTOR' : _CREATEANDEXERCISECOMMAND,
  '__module__' : 'com.daml.ledger.api.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CreateAndExerciseCommand)
  })
_sym_db.RegisterMessage(CreateAndExerciseCommand)


DESCRIPTOR._options = None
_COMMANDS.fields_by_name['deduplication_time']._options = None
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from asyncio import get_event_loop
from datetime import timedelta
import logging
import os
import subprocess
import threading
from typing import Optional, Union

from ..util import ProcessLogger, find_free_port, kill_process_tree, wait_for_process_port

DEFAULT_TIMEOUT = timedelta(seconds=10)


class SandboxLauncher:
    """
    A simple launcher for an in-memory Sandbox.
    """

    def __init__(
        self,
        *,
        project_root: "Union[None, str, os.PathLike]",
        version: "Optional[str]" = None,
        timeout: "Optional[timedelta]" = DEFAULT_TIMEOUT,
    ):
        self._version = version
        self._timeout = timeout
        self._lock = threading.RLock()
        self._project_root = project_root
        self._process = None  # type: Optional[subprocess.Popen]
        self._url = None  # type: Optional[str]

        url = os.environ.get("DAZL_TEST_DAML_LEDGER_URL")
        if url:
            # if we're supposed to use a different already-running implementation,
            # then do that instead
            logging.info(
                "Using the sandbox at %s because `DAZL_TEST_DAML_LEDGER_URL` is defined", url
            )
            self._url = url

    @property
    def url(self) -> str:
        """
        Return a URL that can be used to connect to this running Sandbox.
        """
        u = self._url
        if u is not None:
            return u
        else:
            raise RuntimeError("the sandbox is not running (did you call start()?)")

    def start(self) -> None:
        """
        Start the sandbox and return a URL that can be used to connect to it.
        """
        if self._url is not None:
            return

        port = find_free_port()

        env = os.environ.copy()
        # Running dazl's tests against a different Sandbox merely requires the DAML_SDK_VERSION
        # variable be set to a different value
        if self._version is not None:
            env["DAML_SDK_VERSION"] = self._version

        with self._lock:
            # one last check inside the lock
            if self._url is not None:
                return

            if self._process is not None:
                # this shouldn't ever happen, but we explicitly check for it because running
                # multiple sandbox processes could be very confusing
                raise RuntimeError("we somehow have a process without a URL")

            cwd = None  # type: Union[None, str, os.PathLike]
            if self._project_root:
                cmdline = [
                    "daml",
                    "start",
                    "--start-navigator=no",
                    "--open-browser=no",
                    f"--sandbox-port={port}",
                ]
                cwd = self._project_root
            else:
                cmdline = ["daml", "sandbox", "--port", str(port)]

            self._process = subprocess.Popen(
                cmdline,
                env=env,
                cwd=cwd,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                universal_newlines=True,
            )
            ProcessLogger(self._process, logging.getLogger("sandbox")).start()
            wait_for_process_port(self._process, port, DEFAULT_TIMEOUT)

            self._url = f"http://localhost:{port}"

    def stop(self) -> None:
        """
        Stop the sandbox.
        """
        process = self._process
        if process is not None:
            # Clean up the process that we started. Note that some really old versions of the SDK
            # had issues that left dangling child processes running even after the parent process is
            # killed, so make sure that we find and destroy them too if the parent process doesn't
            # kill its own children quickly enough.
            try:
                kill_process_tree(process)
            finally:
                self._url = None

    def __enter__(self) -> "SandboxLauncher":
        """
        Start the sandbox.
        """
        self.start()
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        """
        Stop the sandbox.
        """
        self.stop()

    async def __aenter__(self) -> "SandboxLauncher":
        """
        Start the sandbox.
        """
        loop = get_event_loop()
        await loop.run_in_executor(None, self.start)
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        """
        Stop the sandbox.
        """
        loop = get_event_loop()
        await loop.run_in_executor(None, self.stop)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/transaction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/transaction.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\025TransactionOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(com/daml/ledger/api/v1/transaction.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/event.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb8\x03\n\x0fTransactionTree\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x16\n\x06offset\x18\x06 \x01(\tR\x06offset\x12Y\n\x0c\x65vents_by_id\x18\x07 \x03(\x0b\x32\x37.com.daml.ledger.api.v1.TransactionTree.EventsByIdEntryR\neventsById\x12$\n\x0eroot_event_ids\x18\x08 \x03(\tR\x0crootEventIds\x1a`\n\x0f\x45ventsByIdEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32!.com.daml.ledger.api.v1.TreeEventR\x05value:\x02\x38\x01J\x04\x08\x05\x10\x06\"\x9d\x01\n\tTreeEvent\x12@\n\x07\x63reated\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v1.CreatedEventH\x00R\x07\x63reated\x12\x46\n\texercised\x18\x02 \x01(\x0b\x32&.com.daml.ledger.api.v1.ExercisedEventH\x00R\texercisedB\x06\n\x04kind\"\x82\x02\n\x0bTransaction\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x35\n\x06\x65vents\x18\x05 \x03(\x0b\x32\x1d.com.daml.ledger.api.v1.EventR\x06\x65vents\x12\x16\n\x06offset\x18\x06 \x01(\tR\x06offsetB\x99\x01\n\x16\x63om.daml.ledger.api.v1B\x15TransactionOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TRANSACTIONTREE_EVENTSBYIDENTRY = _descriptor.Descriptor(
  name='EventsByIdEntry',
  full_name='com.daml.ledger.api.v1.TransactionTree.EventsByIdEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.daml.ledger.api.v1.TransactionTree.EventsByIdEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.daml.ledger.api.v1.TransactionTree.EventsByIdEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=572,
)

_TRANSACTIONTREE = _descriptor.Descriptor(
  name='TransactionTree',
  full_name='com.daml.ledger.api.v1.TransactionTree',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.daml.ledger.api.v1.TransactionTree.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transactionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_id', full_name='com.daml.ledger.api.v1.TransactionTree.command_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commandId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='com.daml.ledger.api.v1.TransactionTree.workflow_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_at', full_name='com.daml.ledger.api.v1.TransactionTree.effective_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='effectiveAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='com.daml.ledger.api.v1.TransactionTree.offset', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events_by_id', full_name='com.daml.ledger.api.v1.TransactionTree.events_by_id', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventsById', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_event_ids', full_name='com.daml.ledger.api.v1.TransactionTree.root_event_ids', index=6,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rootEventIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTIONTREE_EVENTSBYIDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=578,
)


_TREEEVENT = _descriptor.Descriptor(
  name='TreeEvent',
  full_name='com.daml.ledger.api.v1.TreeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created', full_name='com.daml.ledger.api.v1.TreeEvent.created', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='created', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exercised', full_name='com.daml.ledger.api.v1.TreeEvent.exercised', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='exercised', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='com.daml.ledger.api.v1.TreeEvent.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=581,
  serialized_end=738,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='com.daml.ledger.api.v1.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.daml.ledger.api.v1.Transaction.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transactionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_id', full_name='com.daml.ledger.api.v1.Transaction.command_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commandId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='com.daml.ledger.api.v1.Transaction.workflow_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_at', full_name='com.daml.ledger.api.v1.Transaction.effective_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='effectiveAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='com.daml.ledger.api.v1.Transaction.events', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='com.daml.ledger.api.v1.Transaction.offset', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=999,
)

_TRANSACTIONTREE_EVENTSBYIDENTRY.fields_by_name['value'].message_type = _TREEEVENT
_TRANSACTIONTREE_EVENTSBYIDENTRY.containing_type = _TRANSACTIONTREE
_TRANSACTIONTREE.fields_by_name['effective_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSACTIONTREE.fields_by_name['events_by_id'].message_type = _TRANSACTIONTREE_EVENTSBYIDENTRY
_TREEEVENT.fields_by_name['created'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2._CREATEDEVENT
_TREEEVENT.fields_by_name['exercised'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2._EXERCISEDEVENT
_TREEEVENT.oneofs_by_name['kind'].fields.append(
  _TREEEVENT.fields_by_name['created'])
_TREEEVENT.fields_by_name['created'].containing_oneof = _TREEEVENT.oneofs_by_name['kind']
_TREEEVENT.oneofs_by_name['kind'].fields.append(
  _TREEEVENT.fields_by_name['exercised'])
_TREEEVENT.fields_by_name['exercised'].containing_oneof = _TREEEVENT.oneofs_by_name['kind']
_TRANSACTION.fields_by_name['effective_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSACTION.fields_by_name['events'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2._EVENT
DESCRIPTOR.message_types_by_name['TransactionTree'] = _TRANSACTIONTREE
DESCRIPTOR.message_types_by_name['TreeEvent'] = _TREEEVENT
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransactionTree = _reflection.GeneratedProtocolMessageType('TransactionTree', (_message.Message,), {

  'EventsByIdEntry' : _reflection.GeneratedProtocolMessageType('EventsByIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSACTIONTREE_EVENTSBYIDENTRY,
    '__module__' : 'com.daml.ledger.api.v1.transaction_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.TransactionTree.EventsByIdEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSACTIONTREE,
  '__module__' : 'com.daml.ledger.api.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.TransactionTree)
  })
_sym_db.RegisterMessage(TransactionTree)
_sym_db.RegisterMessage(TransactionTree.EventsByIdEntry)

TreeEvent = _reflection.GeneratedProtocolMessageType('TreeEvent', (_message.Message,), {
  'DESCRIPTOR' : _TREEEVENT,
  '__module__' : 'com.daml.ledger.api.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.TreeEvent)
  })
_sym_db.RegisterMessage(TreeEvent)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'com.daml.ledger.api.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Transaction)
  })
_sym_db.RegisterMessage(Transaction)


DESCRIPTOR._options = None
_TRANSACTIONTREE_EVENTSBYIDENTRY._options = None
# @@protoc_insertion_point(module_scope)
